==> down.php?SDK=HIVE_SDK_Android_v4.13.0.5.zip: Android/Sample/app/src/main/java/com/hive/sample/AnalyticsTestView.java <==
package com.hive.sample;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import java.util.Random;
import android.os.Handler;

import android.app.Activity;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import com.hive.Analytics;
import com.hive.base.Property;
import com.hive.base.UrlManager.UrlKeys;
import com.hive.impl.AuthV4Impl;
import com.hive.sample.uihelper.ViewPagerBase;

import com.com2us.hivesdk.normal.freefull.google.global.android.common.R;

import org.json.JSONArray;
import org.json.JSONException;


/**
 * HIVE SDK 의 Analytics 기능 테스트 뷰
 *
 * @author ryuvsken
 */
public class AnalyticsTestView extends ViewPagerBase implements View.OnClickListener {

	private Map<com.hive.Analytics.TrackingType, Spinner> mapSwitchUI;

	private int mYourLevel = 1;
	private ArrayList<String> mYourCharacter = new ArrayList<>();

	private boolean bAnalyticsSend;
	// Initialize a new instance of Handler
	Handler mHandler = new Handler();
	Thread mThread;
	private Runnable runnableCode1 = new Runnable() {
		@Override
		public void run() {
			try {

				while(true) {

					for (int i = 0; i < 10; i++) {
					AnalyticsLogAPI.log_hivesdk_singular_normal_test();
					}
					Thread.sleep(100);
				}
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
		}
	};
	private Runnable runnableCode2 = new Runnable() {
		@Override
		public void run() {
			try {

				while(true) {
					for (int i = 0; i < 10; i++) {
						Log.w("IT'sTEST", "TEST LOG PRINT@@@@@@@@@@@@@@");
					}
	//			mHandler.postDelayed(this, 100);
						Thread.sleep(100);
				}
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
		}
	};

	public AnalyticsTestView(Activity activity, View view, String title) {
		super(activity, view, title);

		initUi();
	}

	private void applyTrackerStatusToUI() {
		// Configuration 정보가 로딩되어 있어야 함.
		// set On by configuration values
		List<com.hive.Analytics.Tracker> arrayTrackers = com.hive.Configuration.getTrackers();

		for (com.hive.Analytics.Tracker tracker : arrayTrackers) {
			if (mapSwitchUI.get(tracker.trackingType) != null) {

				mapSwitchUI.get(tracker.trackingType).setSelection(0);
				Analytics.setEnableTracker(tracker.trackingType, true);
			}
		}
	}

	@SuppressWarnings({ "unchecked", "rawtypes" })
	private void initUi() {

		createLogView(R.id.logview, R.id.btnLogDialog, R.id.btnLogClear);

        TextView tvYourLevel = (TextView)this.view.findViewById(R.id.tvYourLevel);
        Button btnLevelUp = (Button)this.view.findViewById(R.id.btnLevelUp);
        btnLevelUp.setOnClickListener(this);
        tvYourLevel.setText(String.valueOf(mYourLevel));

        TextView tvYourCharacter = (TextView)this.view.findViewById(R.id.tvYourCharacter);
        Button btnChooseCharacter = (Button)this.view.findViewById(R.id.btnChooseCharacter);
        btnChooseCharacter.setOnClickListener(this);
        tvYourCharacter.setText(mYourCharacter.toString());

		ArrayAdapter<CharSequence> spAdapter;

		// Mobile App Tracker on/off
		mapSwitchUI = new HashMap<com.hive.Analytics.TrackingType, Spinner>();

		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("On");
		spAdapter.add("Off");
		((Spinner)this.view.findViewById(R.id.spAdjust)).setAdapter(spAdapter);
		((Spinner)this.view.findViewById(R.id.spAdjust)).setSelection(1);
		mapSwitchUI.put(com.hive.Analytics.TrackingType.ADJUST, ((Spinner)this.view.findViewById(R.id.spAdjust)));


		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("On");
		spAdapter.add("Off");
		((Spinner)this.view.findViewById(R.id.spSingular)).setAdapter(spAdapter);
		((Spinner)this.view.findViewById(R.id.spSingular)).setSelection(1);
		mapSwitchUI.put(Analytics.TrackingType.SINGULAR, ((Spinner)this.view.findViewById(R.id.spSingular)));

		// Mobile App Tracking Event
		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("Install");
		spAdapter.add("Update");
		spAdapter.add("Open");
		spAdapter.add("TutorialComplete");

		((Spinner)this.view.findViewById(R.id.spMATEvent)).setAdapter(spAdapter);
		((Spinner)this.view.findViewById(R.id.spMATEvent)).setSelection(spAdapter.getCount()-1);

		this.view.findViewById(R.id.btnSendMATEvent).setOnClickListener(this);

		// Analytics Log Category1
		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("sdk_test_join");
		spAdapter.add("sdk_test_login");

		((Spinner)this.view.findViewById(R.id.spLogCategory1)).setAdapter(spAdapter);

		((EditText)this.view.findViewById(R.id.edtAnalyticsLogServer)).setText(com.hive.base.UrlManager.getInstance().getUrl(UrlKeys.ANALYTICS.getValue()));
		this.view.findViewById(R.id.btnSendAnalyticsLog).setOnClickListener(this);
		this.view.findViewById(R.id.btnSendAnalyticsLogStart).setOnClickListener(this);
		this.view.findViewById(R.id.btnSendAnalyticsLogStop).setOnClickListener(this);
		bAnalyticsSend = false;
	}


	@Override
	public void onUpdateView() {
		// 테스트 화면으로 올 때마다 설정데이터 기반으로 UI 업데이
		applyTrackerStatusToUI();



        updateLevelAndCharacter();
	}


	private void updateLevelAndCharacter() {

        AuthV4Impl.AccountV4 accountV4 = AuthV4Impl.getAccountV4();

        Property p = Property.getInstance();
        if (!p.isLoaded())
            p.loadProperties();

        TextView tvYourLevel = (TextView)this.view.findViewById(R.id.tvYourLevel);
        Button btnLevelUp = (Button)this.view.findViewById(R.id.btnLevelUp);

        TextView tvYourCharacter = (TextView)this.view.findViewById(R.id.tvYourCharacter);
        Button btnChooseCharacter = (Button)this.view.findViewById(R.id.btnChooseCharacter);

		if (accountV4 != null) {
			if (!TextUtils.isEmpty(accountV4.vid)) {

				String strMyLevel = p.getValue("sample.myLevel" + accountV4.vid, "");
				// 저장되어 있지 않으면 초기 실행으로 판단하여 기본값으로 세팅 및 로그 전송함.
				if (TextUtils.isEmpty(strMyLevel)) {
					strMyLevel = String.valueOf(mYourLevel);
					p.setValue("sample.myLevel" + accountV4.vid, strMyLevel);
					p.writeProperties();
					AnalyticsLogAPI.Account_LevelUp(Integer.valueOf(strMyLevel));
				}
				mYourLevel = Integer.valueOf(strMyLevel);


				String strCharacters = p.getValue("sample.myCharacters" + accountV4.vid, mYourCharacter.toString());
				try {
					if (!TextUtils.isEmpty(strCharacters)) {
						JSONArray jsonCharacterArray = new JSONArray(strCharacters);
						mYourCharacter.clear();
						for (int i = 0; i < 9; i++) {
							String character = jsonCharacterArray.optString(i);
							if (!TextUtils.isEmpty(character)) {
								mYourCharacter.add(character);
							}
						}
					}
				} catch (Exception e) {
					e.printStackTrace();
				}

			}
		}

        tvYourLevel.setText(String.valueOf(mYourLevel));
        tvYourCharacter.setText(mYourCharacter.toString());
    }

	@Override
	public void onClick(View v) {

		int rid = v.getId();

        switch(rid) {

			case R.id.btnLevelUp: {

				AuthV4Impl.AccountV4 accountV4 = AuthV4Impl.getAccountV4();

				if (accountV4 != null) {
					if (!TextUtils.isEmpty(accountV4.vid)) {

						Toast.makeText(this.view.getContext(), "Level Up!!", Toast.LENGTH_SHORT).show();

						mYourLevel++;

						Property p = Property.getInstance();
						if (!p.isLoaded()) {
							p.loadProperties();
						}
						p.setValue("sample.myLevel" + accountV4.vid, String.valueOf(mYourLevel));
						p.writeProperties();
						AnalyticsLogAPI.Account_LevelUp(mYourLevel);
					} else {

						Toast.makeText(this.view.getContext(), "Login First.", Toast.LENGTH_SHORT).show();
					}
				}
                updateLevelAndCharacter();
			}
			break;


			case R.id.btnChooseCharacter: {

                AuthV4Impl.AccountV4 accountV4 = AuthV4Impl.getAccountV4();

				if (accountV4 != null) {
					if (!TextUtils.isEmpty(accountV4.vid)) {

						if (mYourCharacter.size() >= 5) {

							Toast.makeText(this.view.getContext(), "Character Limit(5 per account) Excceeded.", Toast.LENGTH_SHORT).show();

						} else {

							Toast.makeText(this.view.getContext(), "Choose Character!!", Toast.LENGTH_SHORT).show();

							String newCharacter = chooseCharacter(mYourCharacter);
							mYourCharacter.add(newCharacter);

							Property p = Property.getInstance();
							if (!p.isLoaded()) {
								p.loadProperties();
							}
							JSONArray obj = new JSONArray();

							try {
								for (int i = 0; i < mYourCharacter.size(); i++) {
									obj.put(i, mYourCharacter.get(i));
								}
							} catch (JSONException e) {
								e.printStackTrace();
							}
							p.setValue("sample.myCharacters" + accountV4.vid, obj.toString());
							p.writeProperties();
							AnalyticsLogAPI.Account_CharacterGet(newCharacter);
						}
					} else {

						Toast.makeText(this.view.getContext(), "Login First.", Toast.LENGTH_SHORT).show();
					}
				}
                updateLevelAndCharacter();
			}
			break;

			// Mobile App Tracking (3rd-party) Test
			case R.id.btnSendMATEvent: {
				// on/off 적용.
				{
					Spinner spinner = (Spinner)this.view.findViewById(R.id.spAdjust);
					String selectedValue = (String) spinner.getAdapter().getItem(spinner.getSelectedItemPosition());
					Analytics.setEnableTracker(Analytics.TrackingType.ADJUST, selectedValue.equals("On"));

					spinner = (Spinner)this.view.findViewById(R.id.spSingular);
					selectedValue = (String) spinner.getAdapter().getItem(spinner.getSelectedItemPosition());
					Analytics.setEnableTracker(Analytics.TrackingType.SINGULAR, selectedValue.equals("On"));
				}

				Spinner spinner = (Spinner)this.view.findViewById(R.id.spMATEvent);
				String selectedValue = (String) spinner.getAdapter().getItem(spinner.getSelectedItemPosition());

				addLog("\n\n=== 서드파티 이벤트 전송 테스트 ===\n");
				addLog("Analytics.sendEvent(" + selectedValue + ") Called\n");

				Analytics.sendEvent(selectedValue);
			}
				break;


			// Hive Analytics Log System Test
			case R.id.btnSendAnalyticsLog: {

				Spinner spinner;

				spinner = (Spinner)this.view.findViewById(R.id.spLogCategory1);
				int logCategory1 = spinner.getSelectedItemPosition();

				addLog("\n\n=== 앱과 사용자 분석용 Log 전송 테스트 ===\n");

				// 계정
				if(logCategory1 == 0) {

					// 가입
					addLog("Analytics.sendAnalyticsLog() Called by AnalyticsLogAPI.Account_Join()\n");

					AnalyticsLogAPI.Account_Join("user001", "바람돌이");
				}
				// 로그인
				else {

					addLog("Analytics.sendAnalyticsLog() Called by AnalyticsLogAPI.Account_Login()\n");

					AnalyticsLogAPI.Account_Login("user001", 1000000);	// 로그인 시 보유 Gold
				}
			}
			break;
			case R.id.btnSendAnalyticsLogStart: {
				if(bAnalyticsSend == false) {


					bAnalyticsSend = true;
					Spinner spinner;
					spinner = (Spinner) this.view.findViewById(R.id.spLogCategory1);
					int logCategory1 = spinner.getSelectedItemPosition();
					if (logCategory1 == 0) {
						mThread = new Thread(runnableCode1);
					}
					else {
						mThread = new Thread(runnableCode2);
					}
					mThread.start();
				}
			}
			break;

			case R.id.btnSendAnalyticsLogStop: {
				bAnalyticsSend = false;
				if(mThread != null) {
					mThread.interrupt();
					mThread = null;
				}
			}
			break;

		}
	}

    /**
     * #3876 일감 관련
     *
     * @param alreadyChosen
     * @return
     */
	private String chooseCharacter(ArrayList<String> alreadyChosen) {

        ArrayList<String> candidates = new ArrayList<>();

        String[] rawData = {"민병우","유기정","이가희","조지훈","문재호"
                ,"김윤기","윤진영","류명지","최석근","서라현"};

        for (int i = 0 ; i < rawData.length ; i++) {
            if (!alreadyChosen.contains(rawData[i])) {
                candidates.add(rawData[i]);
            }
        }

        Random random = new Random();
        int index = random.nextInt(candidates.size());

        return candidates.get(index);
    }
}

==> down.php?SDK=HIVE_SDK_Android_v4.14.0.3.zip: Android/Sample/app/src/main/java/com/hive/sample/AnalyticsTestView.java <==
package com.hive.sample;

import java.util.ArrayList;
import java.util.Locale;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import java.util.Random;
import android.os.Handler;

import android.app.Activity;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import com.hive.Analytics;
import com.hive.base.Property;
import com.hive.base.UrlManager.UrlKeys;
import com.hive.impl.AuthV4Impl;
import com.hive.impl.ConfigurationImpl;
import com.hive.sample.uihelper.ViewPagerBase;

import com.com2us.hivesdk.normal.freefull.google.global.android.common.R;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;


/**
 * HIVE SDK 의 Analytics 기능 테스트 뷰
 *
 * @author ryuvsken
 */
public class AnalyticsTestView extends ViewPagerBase implements View.OnClickListener {

	private Map<com.hive.Analytics.TrackingType, Spinner> mapSwitchUI;

//	// for Example deprecated in SDK.
//	public enum AnalyticsProviderType {
//
//		SINGULAR("Singular"),
//		ADJUST("Adjust"),
//		APPSFLYER("AppsFlyer");
//
//		private String value;
//
//		private AnalyticsProviderType(String value) {
//			this.value = value;
//		}
//
//		public String getValue() {
//			return this.value;
//		}
//	}

//	private Map<AnalyticsProviderType, Spinner> mapSwitchUI;

	private int mYourLevel = 1;
	private ArrayList<String> mYourCharacter = new ArrayList<>();

	private boolean bAnalyticsSend;
	// Initialize a new instance of Handler
	Handler mHandler = new Handler();
	Thread mThread;
	private Runnable runnableCode1 = new Runnable() {
		@Override
		public void run() {
			try {

				while(true) {

					for (int i = 0; i < 10; i++) {
					AnalyticsLogAPI.log_hivesdk_singular_normal_test();
					}
					Thread.sleep(100);
				}
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
		}
	};
	private Runnable runnableCode2 = new Runnable() {
		@Override
		public void run() {
			try {

				while(true) {
					for (int i = 0; i < 10; i++) {
						Log.w("IT'sTEST", "TEST LOG PRINT@@@@@@@@@@@@@@");
					}
	//			mHandler.postDelayed(this, 100);
						Thread.sleep(100);
				}
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
		}
	};

	public AnalyticsTestView(Activity activity, View view, String title) {
		super(activity, view, title);

		initUi();
	}

	private void applyTrackerStatusToUI() {
		// Configuration 정보가 로딩되어 있어야 함.
		// set On by configuration values

		List<com.hive.Analytics.Tracker> arrayTrackers =  new ArrayList<com.hive.Analytics.Tracker>();
		JSONArray trackerArray = ConfigurationImpl.getInstance().getTrackers();
		JSONObject trackerObject;
		if(trackerArray == null)
			return;

		for(int i = 0; i < trackerArray.length(); i++) {
			trackerObject = trackerArray.optJSONObject(i);
			if (trackerObject == null) {
				continue;
			}
			String trackerName = trackerObject.optString("@name", null);
			com.hive.Analytics.Tracker tracker = new com.hive.Analytics.Tracker();
			try {
				tracker.trackingType = Analytics.TrackingType.valueOf(trackerName.toUpperCase(Locale.US));
			} catch (Exception e) {
				continue;
			}
			arrayTrackers.add(tracker);
		}

		for (com.hive.Analytics.Tracker tracker : arrayTrackers) {
			if (mapSwitchUI.get(tracker.trackingType) != null) {

				mapSwitchUI.get(tracker.trackingType).setSelection(0);
				Analytics.setEnableTracker(tracker.trackingType, true);
			}
		}
//		List<AnalyticsProviderType> arrayTrackers =  new ArrayList<AnalyticsProviderType>();
//		JSONArray trackerArray = ConfigurationImpl.getInstance().getTrackers();
//		JSONObject trackerObject;
//		if(trackerArray == null)
//			return;
//		for(int i = 0; i < trackerArray.length(); i++) {
//			trackerObject = trackerArray.optJSONObject(i);
//			if (trackerObject == null) {
//				continue;
//			}
//			String trackerName = trackerObject.optString("@name", null);
////			com.hive.Analytics.Tracker tracker = new com.hive.Analytics.Tracker();
//			AnalyticsProviderType parsedType;
//			try {
//				parsedType = AnalyticsProviderType.valueOf(trackerName.toUpperCase(Locale.US));
//				arrayTrackers.add(parsedType);
//			} catch (Exception e) {
//				continue;
//			}
//		}
//
//		for (AnalyticsProviderType tracker : arrayTrackers) {
//			if (mapSwitchUI.get(tracker.getValue()) != null) {
//
//				mapSwitchUI.get(tracker.getValue()).setSelection(0);
//				Analytics.setEnableTracker(tracker.value, true);
//			}
//		}
	}

	@SuppressWarnings({ "unchecked", "rawtypes" })
	private void initUi() {

		createLogView(R.id.logview, R.id.btnLogDialog, R.id.btnLogClear);

        TextView tvYourLevel = (TextView)this.view.findViewById(R.id.tvYourLevel);
        Button btnLevelUp = (Button)this.view.findViewById(R.id.btnLevelUp);
        btnLevelUp.setOnClickListener(this);
        tvYourLevel.setText(String.valueOf(mYourLevel));

        TextView tvYourCharacter = (TextView)this.view.findViewById(R.id.tvYourCharacter);
        Button btnChooseCharacter = (Button)this.view.findViewById(R.id.btnChooseCharacter);
        btnChooseCharacter.setOnClickListener(this);
        tvYourCharacter.setText(mYourCharacter.toString());

		ArrayAdapter<CharSequence> spAdapter;

		// Mobile App Tracker on/off
		mapSwitchUI = new HashMap<com.hive.Analytics.TrackingType, Spinner>();

		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("On");
		spAdapter.add("Off");
		((Spinner)this.view.findViewById(R.id.spAdjust)).setAdapter(spAdapter);
		((Spinner)this.view.findViewById(R.id.spAdjust)).setSelection(1);
		mapSwitchUI.put(com.hive.Analytics.TrackingType.ADJUST, ((Spinner)this.view.findViewById(R.id.spAdjust)));


		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("On");
		spAdapter.add("Off");
		((Spinner)this.view.findViewById(R.id.spSingular)).setAdapter(spAdapter);
		((Spinner)this.view.findViewById(R.id.spSingular)).setSelection(1);
		mapSwitchUI.put(Analytics.TrackingType.SINGULAR, ((Spinner)this.view.findViewById(R.id.spSingular)));

		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("On");
		spAdapter.add("Off");
		((Spinner)this.view.findViewById(R.id.spAppsFlyer)).setAdapter(spAdapter);
		((Spinner)this.view.findViewById(R.id.spAppsFlyer)).setSelection(1);
		mapSwitchUI.put(Analytics.TrackingType.APPSFLYER, ((Spinner)this.view.findViewById(R.id.spAppsFlyer)));

		// Mobile App Tracking Event
		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("Install");
		spAdapter.add("Update");
		spAdapter.add("Open");
		spAdapter.add("TutorialComplete");

		((Spinner)this.view.findViewById(R.id.spMATEvent)).setAdapter(spAdapter);
		((Spinner)this.view.findViewById(R.id.spMATEvent)).setSelection(spAdapter.getCount()-1);

		this.view.findViewById(R.id.btnSendMATEvent).setOnClickListener(this);

		// Analytics Log Category1
		spAdapter = new ArrayAdapter(activity, android.R.layout.simple_spinner_item);
		spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		spAdapter.add("sdk_test_join");
		spAdapter.add("sdk_test_login");

		((Spinner)this.view.findViewById(R.id.spLogCategory1)).setAdapter(spAdapter);

		((EditText)this.view.findViewById(R.id.edtAnalyticsLogServer)).setText(com.hive.base.UrlManager.getInstance().getUrl(UrlKeys.ANALYTICS.getValue()));
		this.view.findViewById(R.id.btnSendAnalyticsLog).setOnClickListener(this);
		this.view.findViewById(R.id.btnSendAnalyticsLogStart).setOnClickListener(this);
		this.view.findViewById(R.id.btnSendAnalyticsLogStop).setOnClickListener(this);
		bAnalyticsSend = false;
	}


	@Override
	public void onUpdateView() {
		// 테스트 화면으로 올 때마다 설정데이터 기반으로 UI 업데이
		applyTrackerStatusToUI();



        updateLevelAndCharacter();
	}


	private void updateLevelAndCharacter() {

        AuthV4Impl.AccountV4 accountV4 = AuthV4Impl.getAccountV4();

        Property p = Property.getInstance();
        if (!p.isLoaded())
            p.loadProperties();

        TextView tvYourLevel = (TextView)this.view.findViewById(R.id.tvYourLevel);
        Button btnLevelUp = (Button)this.view.findViewById(R.id.btnLevelUp);

        TextView tvYourCharacter = (TextView)this.view.findViewById(R.id.tvYourCharacter);
        Button btnChooseCharacter = (Button)this.view.findViewById(R.id.btnChooseCharacter);

		if (accountV4 != null) {
			if (!TextUtils.isEmpty(accountV4.vid)) {

				String strMyLevel = p.getValue("sample.myLevel" + accountV4.vid, "");
				// 저장되어 있지 않으면 초기 실행으로 판단하여 기본값으로 세팅 및 로그 전송함.
				if (TextUtils.isEmpty(strMyLevel)) {
					strMyLevel = String.valueOf(mYourLevel);
					p.setValue("sample.myLevel" + accountV4.vid, strMyLevel);
					p.writeProperties();
					AnalyticsLogAPI.Account_LevelUp(Integer.valueOf(strMyLevel));
				}
				mYourLevel = Integer.valueOf(strMyLevel);


				String strCharacters = p.getValue("sample.myCharacters" + accountV4.vid, mYourCharacter.toString());
				try {
					if (!TextUtils.isEmpty(strCharacters)) {
						JSONArray jsonCharacterArray = new JSONArray(strCharacters);
						mYourCharacter.clear();
						for (int i = 0; i < 9; i++) {
							String character = jsonCharacterArray.optString(i);
							if (!TextUtils.isEmpty(character)) {
								mYourCharacter.add(character);
							}
						}
					}
				} catch (Exception e) {
					e.printStackTrace();
				}

			}
		}

        tvYourLevel.setText(String.valueOf(mYourLevel));
        tvYourCharacter.setText(mYourCharacter.toString());
    }

	@Override
	public void onClick(View v) {

		int rid = v.getId();

        switch(rid) {

			case R.id.btnLevelUp: {

				AuthV4Impl.AccountV4 accountV4 = AuthV4Impl.getAccountV4();

				if (accountV4 != null) {
					if (!TextUtils.isEmpty(accountV4.vid)) {

						Toast.makeText(this.view.getContext(), "Level Up!!", Toast.LENGTH_SHORT).show();

						mYourLevel++;

						Property p = Property.getInstance();
						if (!p.isLoaded()) {
							p.loadProperties();
						}
						p.setValue("sample.myLevel" + accountV4.vid, String.valueOf(mYourLevel));
						p.writeProperties();
						AnalyticsLogAPI.Account_LevelUp(mYourLevel);
					} else {

						Toast.makeText(this.view.getContext(), "Login First.", Toast.LENGTH_SHORT).show();
					}
				}
                updateLevelAndCharacter();
			}
			break;


			case R.id.btnChooseCharacter: {

                AuthV4Impl.AccountV4 accountV4 = AuthV4Impl.getAccountV4();

				if (accountV4 != null) {
					if (!TextUtils.isEmpty(accountV4.vid)) {

						if (mYourCharacter.size() >= 5) {

							Toast.makeText(this.view.getContext(), "Character Limit(5 per account) Excceeded.", Toast.LENGTH_SHORT).show();

						} else {

							Toast.makeText(this.view.getContext(), "Choose Character!!", Toast.LENGTH_SHORT).show();

							String newCharacter = chooseCharacter(mYourCharacter);
							mYourCharacter.add(newCharacter);

							Property p = Property.getInstance();
							if (!p.isLoaded()) {
								p.loadProperties();
							}
							JSONArray obj = new JSONArray();

							try {
								for (int i = 0; i < mYourCharacter.size(); i++) {
									obj.put(i, mYourCharacter.get(i));
								}
							} catch (JSONException e) {
								e.printStackTrace();
							}
							p.setValue("sample.myCharacters" + accountV4.vid, obj.toString());
							p.writeProperties();
							AnalyticsLogAPI.Account_CharacterGet(newCharacter);
						}
					} else {

						Toast.makeText(this.view.getContext(), "Login First.", Toast.LENGTH_SHORT).show();
					}
				}
                updateLevelAndCharacter();
			}
			break;

			// Mobile App Tracking (3rd-party) Test
			case R.id.btnSendMATEvent: {
				// on/off 적용.
				{
					Spinner spinner = (Spinner)this.view.findViewById(R.id.spAdjust);
					String selectedValue = (String) spinner.getAdapter().getItem(spinner.getSelectedItemPosition());
					Analytics.setEnableTracker(Analytics.TrackingType.ADJUST, selectedValue.equals("On"));

					spinner = (Spinner)this.view.findViewById(R.id.spSingular);
					selectedValue = (String) spinner.getAdapter().getItem(spinner.getSelectedItemPosition());
					Analytics.setEnableTracker(Analytics.TrackingType.SINGULAR, selectedValue.equals("On"));

					spinner = (Spinner)this.view.findViewById(R.id.spAppsFlyer);
					selectedValue = (String) spinner.getAdapter().getItem(spinner.getSelectedItemPosition());
					Analytics.setEnableTracker(Analytics.TrackingType.APPSFLYER, selectedValue.equals("On"));
				}

				Spinner spinner = (Spinner)this.view.findViewById(R.id.spMATEvent);
				String selectedValue = (String) spinner.getAdapter().getItem(spinner.getSelectedItemPosition());

				addLog("\n\n=== 서드파티 이벤트 전송 테스트 ===\n");
				addLog("Analytics.sendEvent(" + selectedValue + ") Called\n");

				Analytics.sendEvent(selectedValue);
			}
				break;


			// Hive Analytics Log System Test
			case R.id.btnSendAnalyticsLog: {

				Spinner spinner;

				spinner = (Spinner)this.view.findViewById(R.id.spLogCategory1);
				int logCategory1 = spinner.getSelectedItemPosition();

				addLog("\n\n=== 앱과 사용자 분석용 Log 전송 테스트 ===\n");

				// 계정
				if(logCategory1 == 0) {

					// 가입
					addLog("Analytics.sendAnalyticsLog() Called by AnalyticsLogAPI.Account_Join()\n");

					AnalyticsLogAPI.Account_Join("user001", "바람돌이");
				}
				// 로그인
				else {

					addLog("Analytics.sendAnalyticsLog() Called by AnalyticsLogAPI.Account_Login()\n");

					AnalyticsLogAPI.Account_Login("user001", 1000000);	// 로그인 시 보유 Gold
				}
			}
			break;
			case R.id.btnSendAnalyticsLogStart: {
				if(bAnalyticsSend == false) {


					bAnalyticsSend = true;
					Spinner spinner;
					spinner = (Spinner) this.view.findViewById(R.id.spLogCategory1);
					int logCategory1 = spinner.getSelectedItemPosition();
					if (logCategory1 == 0) {
						mThread = new Thread(runnableCode1);
					}
					else {
						mThread = new Thread(runnableCode2);
					}
					mThread.start();
				}
			}
			break;

			case R.id.btnSendAnalyticsLogStop: {
				bAnalyticsSend = false;
				if(mThread != null) {
					mThread.interrupt();
					mThread = null;
				}
			}
			break;

		}
	}

    /**
     * #3876 일감 관련
     *
     * @param alreadyChosen
     * @return
     */
	private String chooseCharacter(ArrayList<String> alreadyChosen) {

        ArrayList<String> candidates = new ArrayList<>();

        String[] rawData = {"민병우","유기정","이가희","조지훈","문재호"
                ,"김윤기","윤진영","류명지","최석근","서라현"};

        for (int i = 0 ; i < rawData.length ; i++) {
            if (!alreadyChosen.contains(rawData[i])) {
                candidates.add(rawData[i]);
            }
        }

        Random random = new Random();
        int index = random.nextInt(candidates.size());

        return candidates.get(index);
    }
}
